Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(903)

Unified Diff: ppapi/proxy/ppp_instance_private_proxy_unittest.cc

Issue 400823004: gin (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ppapi/proxy/ppb_testing_proxy.cc ('k') | ppapi/shared_impl/scoped_pp_var.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ppapi/proxy/ppp_instance_private_proxy_unittest.cc
diff --git a/ppapi/proxy/ppp_instance_private_proxy_unittest.cc b/ppapi/proxy/ppp_instance_private_proxy_unittest.cc
index abafa87d0e8465a05e791116d95cead9aa32fc7e..f9a54e4f40cb628cea49296d89f43e25a5490c4f 100644
--- a/ppapi/proxy/ppp_instance_private_proxy_unittest.cc
+++ b/ppapi/proxy/ppp_instance_private_proxy_unittest.cc
@@ -21,14 +21,14 @@
namespace ppapi {
-// A fake version of NPObjectVar for testing.
-class NPObjectVar : public ppapi::Var {
+// A fake version of V8ObjectVar for testing.
+class V8ObjectVar : public ppapi::Var {
public:
- NPObjectVar() {}
- virtual ~NPObjectVar() {}
+ V8ObjectVar() {}
+ virtual ~V8ObjectVar() {}
// Var overrides.
- virtual NPObjectVar* AsNPObjectVar() OVERRIDE { return this; }
+ virtual V8ObjectVar* AsV8ObjectVar() OVERRIDE { return this; }
virtual PP_VarType GetType() const OVERRIDE { return PP_VARTYPE_OBJECT; }
};
@@ -111,7 +111,7 @@ PPP_Instance_1_0 ppp_instance_mock = { &DidCreate, &DidDestroy };
PP_Var CreateObject(PP_Instance /*instance*/,
const PPP_Class_Deprecated* /*ppp_class*/,
void* /*ppp_class_data*/) {
- NPObjectVar* obj_var = new NPObjectVar;
+ V8ObjectVar* obj_var = new V8ObjectVar;
return obj_var->GetPPVar();
}
« no previous file with comments | « ppapi/proxy/ppb_testing_proxy.cc ('k') | ppapi/shared_impl/scoped_pp_var.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698